%global short_name commons-launcher

Name:          apache-%{short_name}
Version:       1.1
Release:       23.20100521svn936225%{?dist}
Summary:       A cross platform Java application launcher
License:       ASL 2.0
URL:           http://commons.apache.org/launcher/

# The last release of this package was many years ago and in that time there
# have only been two extremely minor changes to the source code, [1] and [2].
# It seems a new release is unlikely to be forthcoming in the near future.
# 
# [1] - http://svn.apache.org/viewvc/commons/proper/launcher/trunk/src/java/org/apache/commons/launcher/ChildMain.java?r1=138801&r2=138803
# [2] - http://svn.apache.org/viewvc/commons/proper/launcher/trunk/src/java/org/apache/commons/launcher/Launcher.java?r1=138801&r2=138802
# 
# During that time however, support for the maven 2 build system has been
# added. So in order to make my life easier as a maintainer, with regard to
# supporting OSGi manifests and installing poms, etc, I have elected to package
# a maven2 supporting snapshot instead of maintaining patches in our SRPM. As
# an added bonus, the snapshot also has more accurate javadocs.
# 
# How to generate source tarball from source control:
#  $ svn export -r 936225 http://svn.apache.org/repos/asf/commons/proper/launcher/trunk/ commons-launcher-1.1-src
#  $ tar -zcf commons-launcher-1.1-src.tar.gz commons-launcher-1.1-src
Source0:       %{short_name}-%{version}-src.tar.gz

# remove unnecessary build dependency on ant-optional (ant no longer ships this jar)
Patch0:        %{short_name}-pom.patch

BuildArch:     noarch

BuildRequires:  maven-local
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.ant:ant)
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)

%description
Commons-launcher eliminates the need for a batch or shell script to launch a 
Java class. Some situations where elimination of a batch or shell script may 
be desirable are:

* You want to avoid having to determining where certain application paths are
e.g. your application's home directory, etc. Determining this dynamically in 
a Windows batch scripts is very tricky on some versions of Windows or when 
soft links are used on Unix platforms.

* You want to avoid having to handle native file and path separators or native
path quoting issues.

* You need to enforce certain system properties.

* You want to allow users to pass in custom JVM arguments or system properties
without having to parse and reorder arguments in your script. This can be 
tricky and/or messy in batch and shell scripts.

* You want to bootstrap system properties from a configuration file instead 
hard-coding them in your batch and shell scripts.

* You want to provide localized error messages which is very tricky to do in
batch and shell scripts.

%package javadoc
Summary:       API documentation for %{name}

%description javadoc
%{summary}.

%prep
%setup -q -n %{short_name}-%{version}-src

# apply patches
%patch0 -p0 -b .orig

sed -i 's/\r//' README.txt LICENSE.txt NOTICE.txt
sed -i "s|\<groupId\>ant\<\/groupId\>|<groupId>org.apache.ant</groupId>|g" build.xml

# This class is for working around PATH problems on Windows platforms only but
# prevents building here because OSGi does not permit classes in the default
# package. Remove for now, to appease newer maven-bundle-plugin versions.
rm src/java/LauncherBootstrap.java

# Compatibility links
%mvn_alias "%{short_name}:%{short_name}" "org.apache.commons:%{short_name}"
%mvn_file :commons-launcher %{short_name} %{name}

%build
%mvn_build

%install
%mvn_install

%files -f .mfiles
%license LICENSE.txt NOTICE.txt
%doc README.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt

%changelog
* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-23.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-22.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-21.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-20.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-19.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Feb 05 2016 Mat Booth <mat.booth@redhat.com> - 1.1-18.20100521svn936225
- Fix FTBFS caused by strict new bnd version.
- Adopt %%license macro

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.1-17.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-16.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-15.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Aug 5 2013 Mat Booth <fedora@matbooth.co.uk> - 1.1-14.20100521svn936225
- Update for newer guidelines

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-13.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Mon Feb 18 2013 Java SIG <java-devel@lists.fedoraproject.org> - 1.1-12.20100521svn936225
- Update for https://fedoraproject.org/wiki/Fedora_19_Maven_Rebuild
- Replace maven BuildRequires with maven-local

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-11.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sun Aug 5 2012 Mat Booth <fedora@matbooth.co.uk> - 1.1-10.20100521svn936225
- Remove old obsolete/provides.
- Build with maven3.
- Install versionless artifacts only.
- Conform more to newer guidelines.

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-9.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-8.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1-7.20100521svn936225
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 8 2010 Alexander Kurtakov <akurtako@redhat.com> 1.1-6.20100521svn936225
- Fix build due to changed ant groupId.

* Fri May 21 2010 Mat Booth <fedora@matbooth.co.uk> - 1.1-5.20100521svn936225
- Version like a post release snapshot, not a pre release snapshot.
- Correct dep-map names.

* Sat May 15 2010 Mat Booth <fedora@matbooth.co.uk>
- Rename package (jakarta-commons-launcher->apache-commons-launcher).
- Update to 1.2 snapshot.
- Rewrite spec file to build using upstream-preferred maven instead of ant.
- Install pom and add to maven dep-map.
- Require Java 1.6 because javadoc generation fails on GCJ.
- Drop GCJ AOT support.
- Use global instead of define.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.1-4.4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.1-3.4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jul  9 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0:1.1-2.4
- drop repotag
- fix license tag

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0:1.1-2jpp.3
- Autorebuild for GCC 4.3

* Fri Sep 07 2007 Matt Wringe <mwringe@redhat.com> - 0:1.1-1jpp.3
- Fix unowned directory

* Fri Feb 09 2007 Matt Wringe <mwringe@redhat.com> - 0:1.1-1jpp.2
- Fix macro naming for post and postun

* Tue Feb 06 2007 Matt Wringe <mwringe@redhat.com> - 0:1.1-1jpp.1
- Merge with upstream jpp spec file
- Add missing jpackage utils requirements on pre and postun
- Add missing requires on java
- Fix some rpmlint issues 

* Fri Nov 17 2006 Jason Corley <jason.corley@gmail.com> - 0:1.1-1jpp
- 1.1
